# Table Header Scope Attribute

In a table, the scope attribute indicates the direction and range of data cells
covered by `<th>` elements. The Table Header Scope Attribute module provides a
text format filter, that processes a `<table>` and sets the correct `scope`
attribute to `<th>` elements.

For example, the following table:

```html
<table>
  <thead>
    <tr>
      <th>Column header 1</th>
      <th>Column header 2</th>
    </tr>
  </thead>
  <tbody>
    <tr>
      <th>Row header 1</th>
      <td>Value 1</td>
    </tr>
    <tr>
      <th>Row header 2</th>
      <td>Value 2</td>
    </tr>
  </tbody>
</table>
```

Will be transformed to:

```html
<table>
  <thead>
    <tr>
      <th scope="col">Column header 1</th>
      <th scope="col">Column header 2</th>
    </tr>
  </thead>
  <tbody>
    <tr>
      <th scope="row">Row header 1</th>
      <td>Value 1</td>
    </tr>
    <tr>
      <th scope="row">Row header 2</th>
      <td>Value 2</td>
    </tr>
  </tbody>
</table>
```

For a full description of the module, visit the
[project page](https://www.drupal.org/project/table_header_scope_attribute).

Submit bug reports and feature suggestions, or track changes in the
[issue queue](https://www.drupal.org/project/issues/table_header_scope_attribute).

## REQUIREMENTS

This module requires no modules outside of Drupal core.


## INSTALLATION

Install as you would normally install a contributed Drupal module. For further
information, see
[Installing Drupal Modules](https://www.drupal.org/docs/extending-drupal/installing-drupal-modules).


## CONFIGURATION

1. Go to Administration » Configuration » Content authoring » Text formats
   and editors
1. Edit a text format, for example, "Basic HTML"
1. Enable the "Set scope attribute for table headers" filter
1. Ensure that this filter is below the "Limit allowed HTML tags and correct
   faulty HTML" filter in the processing order of filters

Assuming the filter is enabled for a text format that can be used on, e.g., a
basic page (node). Create or edit a basic page and enter a table. Indicate the
`<th>` elements in the `<table>` and save the node. When viewing the (source of
the) basic page, the scope attributes are correctly set to the `<th>` tags.
